@@ -31,6 +31,7 @@ pub(crate) mod non_critical_lints {
     pub mod no_obj_calls;
     pub mod no_param_reassign;
     pub mod no_restricted_syntax;
+    pub mod no_sparse_arrays;
     pub mod no_throw_literal;
     pub mod no_use_before_define;
     pub mod no_var;
@@ -171,6 +172,10 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
         rules.extend(no_compare_neg_zero::no_compare_neg_zero(
             &lint_config.no_compare_neg_zero,
         ));
+
+        rules.extend(no_sparse_arrays::no_sparse_arrays(
+            &lint_config.no_sparse_arrays,
+        ));
     }
 
     rules
